@@ -1,6 +1,6 @@
 """Linton 'publish' subcommand
 
-© Reuben Thomas <rrt@sc3d.org> 2024
+© Reuben Thomas <rrt@sc3d.org> 2024-2025
 Released under the GPL version 3, or (at your option) any later version.
 """
 
@@ -9,14 +9,11 @@ import os
 import shutil
 import subprocess
 
-from linton.argparse_util import add_subcommand_arguments
 from linton.warnings_util import die
 
 
-def run(args: argparse.Namespace, render_env: dict[str, str]) -> None:
+def run(args: argparse.Namespace) -> None:
     """'publish' command handler"""
-    render_env["LINTON_DOCUMENT_ROOT"] = args.document_root
-
     # Check output either does not exist, or is an empty directory, unless
     # --force given.
     if os.path.exists(args.output) and not (
@@ -27,17 +24,24 @@ def run(args: argparse.Namespace, render_env: dict[str, str]) -> None:
         shutil.rmtree(args.output)
 
     # Render the project files to the output
-    subprocess.check_output(["nancy", args.document_root, args.output], env=render_env)
+    subprocess.check_output(["nancy", args.document_root, args.output])
+
+    # Check links unless disabled.
+    output_dir = args.output
+    if not output_dir.endswith("/"):
+        output_dir += "/"
+    if not args.no_check_links:
+        subprocess.check_call(["linkchecker", output_dir])
 
 
-def add_subparser(subparsers: argparse._SubParsersAction) -> None:  # type: ignore[type-arg]
+def add_subparser(subparsers: argparse._SubParsersAction) -> None:
     parser = subparsers.add_parser(
         "publish",
-        help="convert a directory of Markdown files and other resources into a web site.",
-        epilog="The output DIRECTORY cannot be a subdirectory of the source directory.",
+        help="convert a directory of Markdown files and other resources into a web site",
+        epilog="The output DIRECTORY cannot be a subdirectory of the input directory.",
     )
     parser.add_argument(
-        "--force",
+        "-f", "--force",
         action="store_true",
         help="overwrite output directory even if it is not empty",
     )
@@ -47,6 +51,13 @@ def add_subparser(subparsers: argparse._SubParsersAction) -> None:  # type: igno
         help="base URL of web site relative to root of server [default: %(default)s]",
         default="/",
     )
-    add_subcommand_arguments(parser)
+    parser.add_argument(
+        "--no-check-links",
+        action="store_true",
+        help="don't check hyperlinks in the generated site",
+    )
+    parser.add_argument(
+        "document_root", metavar="DIRECTORY", help="directory containing source files"
+    )
     parser.add_argument("output", metavar="DIRECTORY", help="output directory")
     parser.set_defaults(func=run)
