@@ -1,21 +1,19 @@
 """Linton 'serve' subcommand
 
-© Reuben Thomas <rrt@sc3d.org> 2024
+© Reuben Thomas <rrt@sc3d.org> 2024-2025
 Released under the GPL version 3, or (at your option) any later version.
 """
 
 import argparse
 import os
 import subprocess
-import urllib
+import urllib.parse
 from http.server import BaseHTTPRequestHandler, HTTPServer
 
 from xdg import Mime
 
-from linton.argparse_util import add_subcommand_arguments
 
-
-def run(args: argparse.Namespace, render_env: dict[str, str]) -> None:
+def run(args: argparse.Namespace) -> None:
     """'serve' command handler"""
 
     class HTTPRequestHandler(BaseHTTPRequestHandler):
@@ -50,7 +48,6 @@ def run(args: argparse.Namespace, render_env: dict[str, str]) -> None:
                 if expand:
                     output = subprocess.check_output(
                         ["nancy", args.document_root, "-", f"--path={url_path}"],
-                        env=render_env,
                     )
                 else:
                     with open(filename, "rb") as fh:
@@ -60,17 +57,28 @@ def run(args: argparse.Namespace, render_env: dict[str, str]) -> None:
                 self.end_headers()
                 self.wfile.write(output)
 
-    render_env["LINTON_DOCUMENT_ROOT"] = args.document_root
-    httpd = HTTPServer(("localhost", 0), HTTPRequestHandler)
+    httpd = HTTPServer(("localhost", args.port), HTTPRequestHandler)
     [host, port] = httpd.server_address
     print(f"Connect to server at http://{str(host)}:{port}/index.html")
     httpd.serve_forever()
 
 
-def add_subparser(subparsers: argparse._SubParsersAction) -> None:  # type: ignore[type-arg]
+def add_subparser(subparsers: argparse._SubParsersAction) -> None:
     parser = subparsers.add_parser(
         "serve",
         help="serve a Linton web site locally on your computer, for testing",
     )
-    add_subcommand_arguments(parser)
+    parser.add_argument(
+        "--port",
+        help="port on which to listen [default: random]",
+        type=int,
+        default=0,
+    )
+    parser.add_argument(
+        "document_root",
+        metavar="DIRECTORY",
+        help="directory containing source files [default: current working directory]",
+        default=os.getcwd(),
+        nargs="?",
+    )
     parser.set_defaults(func=run)
